affected_apps

package
v1.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2024 License: MPL-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockMatcher

type MockMatcher struct {
	mock.Mock
}

MockMatcher is an autogenerated mock type for the Matcher type

func NewMockMatcher

func NewMockMatcher(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockMatcher

NewMockMatcher creates a new instance of MockMatcher. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockMatcher) AffectedApps

func (_m *MockMatcher) AffectedApps(ctx context.Context, changeList []string, targetBranch string, repo *git.Repo) (affected_apps.AffectedItems, error)

AffectedApps provides a mock function with given fields: ctx, changeList, targetBranch, repo

func (*MockMatcher) EXPECT

func (_m *MockMatcher) EXPECT() *MockMatcher_Expecter

type MockMatcher_AffectedApps_Call

type MockMatcher_AffectedApps_Call struct {
	*mock.Call
}

MockMatcher_AffectedApps_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'AffectedApps'

func (*MockMatcher_AffectedApps_Call) Return

func (*MockMatcher_AffectedApps_Call) Run

func (_c *MockMatcher_AffectedApps_Call) Run(run func(ctx context.Context, changeList []string, targetBranch string, repo *git.Repo)) *MockMatcher_AffectedApps_Call

func (*MockMatcher_AffectedApps_Call) RunAndReturn

type MockMatcher_Expecter

type MockMatcher_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockMatcher_Expecter) AffectedApps

func (_e *MockMatcher_Expecter) AffectedApps(ctx interface{}, changeList interface{}, targetBranch interface{}, repo interface{}) *MockMatcher_AffectedApps_Call

AffectedApps is a helper method to define mock.On call

  • ctx context.Context
  • changeList []string
  • targetBranch string
  • repo *git.Repo

type MockargoClient

type MockargoClient struct {
	mock.Mock
}

MockargoClient is an autogenerated mock type for the argoClient type

func NewMockargoClient

func NewMockargoClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockargoClient

NewMockargoClient creates a new instance of MockargoClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockargoClient) EXPECT

func (*MockargoClient) GetApplications

func (_m *MockargoClient) GetApplications(ctx context.Context) (*v1alpha1.ApplicationList, error)

GetApplications provides a mock function with given fields: ctx

func (*MockargoClient) GetApplicationsByAppset

func (_m *MockargoClient) GetApplicationsByAppset(ctx context.Context, appsetName string) (*v1alpha1.ApplicationList, error)

GetApplicationsByAppset provides a mock function with given fields: ctx, appsetName

type MockargoClient_Expecter

type MockargoClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockargoClient_Expecter) GetApplications

func (_e *MockargoClient_Expecter) GetApplications(ctx interface{}) *MockargoClient_GetApplications_Call

GetApplications is a helper method to define mock.On call

  • ctx context.Context

func (*MockargoClient_Expecter) GetApplicationsByAppset

func (_e *MockargoClient_Expecter) GetApplicationsByAppset(ctx interface{}, appsetName interface{}) *MockargoClient_GetApplicationsByAppset_Call

GetApplicationsByAppset is a helper method to define mock.On call

  • ctx context.Context
  • appsetName string

type MockargoClient_GetApplicationsByAppset_Call

type MockargoClient_GetApplicationsByAppset_Call struct {
	*mock.Call
}

MockargoClient_GetApplicationsByAppset_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetApplicationsByAppset'

func (*MockargoClient_GetApplicationsByAppset_Call) Return

func (*MockargoClient_GetApplicationsByAppset_Call) Run

func (*MockargoClient_GetApplicationsByAppset_Call) RunAndReturn

type MockargoClient_GetApplications_Call

type MockargoClient_GetApplications_Call struct {
	*mock.Call
}

MockargoClient_GetApplications_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetApplications'

func (*MockargoClient_GetApplications_Call) Return

func (*MockargoClient_GetApplications_Call) Run

func (*MockargoClient_GetApplications_Call) RunAndReturn

Jump to