generator

package
v1.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2024 License: MPL-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAppsGenerator

type MockAppsGenerator struct {
	mock.Mock
}

MockAppsGenerator is an autogenerated mock type for the AppsGenerator type

func NewMockAppsGenerator

func NewMockAppsGenerator(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockAppsGenerator

NewMockAppsGenerator creates a new instance of MockAppsGenerator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockAppsGenerator) EXPECT

func (*MockAppsGenerator) GenerateApplicationSetApps

func (_m *MockAppsGenerator) GenerateApplicationSetApps(ctx context.Context, appset v1alpha1.ApplicationSet, ctr *container.Container) ([]v1alpha1.Application, error)

GenerateApplicationSetApps provides a mock function with given fields: ctx, appset, ctr

type MockAppsGenerator_Expecter

type MockAppsGenerator_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockAppsGenerator_Expecter) GenerateApplicationSetApps

func (_e *MockAppsGenerator_Expecter) GenerateApplicationSetApps(ctx interface{}, appset interface{}, ctr interface{}) *MockAppsGenerator_GenerateApplicationSetApps_Call

GenerateApplicationSetApps is a helper method to define mock.On call

  • ctx context.Context
  • appset v1alpha1.ApplicationSet
  • ctr *container.Container

type MockAppsGenerator_GenerateApplicationSetApps_Call

type MockAppsGenerator_GenerateApplicationSetApps_Call struct {
	*mock.Call
}

MockAppsGenerator_GenerateApplicationSetApps_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GenerateApplicationSetApps'

func (*MockAppsGenerator_GenerateApplicationSetApps_Call) Return

func (*MockAppsGenerator_GenerateApplicationSetApps_Call) Run

type MockGenerator

type MockGenerator struct {
	mock.Mock
}

MockGenerator is an autogenerated mock type for the Generator type

func NewMockGenerator

func NewMockGenerator(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockGenerator

NewMockGenerator creates a new instance of MockGenerator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockGenerator) EXPECT

func (_m *MockGenerator) EXPECT() *MockGenerator_Expecter

func (*MockGenerator) GenerateParams

func (_m *MockGenerator) GenerateParams(appSetGenerator *v1alpha1.ApplicationSetGenerator, applicationSetInfo *v1alpha1.ApplicationSet) ([]map[string]interface{}, error)

GenerateParams provides a mock function with given fields: appSetGenerator, applicationSetInfo

func (*MockGenerator) GetRequeueAfter

func (_m *MockGenerator) GetRequeueAfter(appSetGenerator *v1alpha1.ApplicationSetGenerator) time.Duration

GetRequeueAfter provides a mock function with given fields: appSetGenerator

func (*MockGenerator) GetTemplate

GetTemplate provides a mock function with given fields: appSetGenerator

type MockGenerator_Expecter

type MockGenerator_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockGenerator_Expecter) GenerateParams

func (_e *MockGenerator_Expecter) GenerateParams(appSetGenerator interface{}, applicationSetInfo interface{}) *MockGenerator_GenerateParams_Call

GenerateParams is a helper method to define mock.On call

  • appSetGenerator *v1alpha1.ApplicationSetGenerator
  • applicationSetInfo *v1alpha1.ApplicationSet

func (*MockGenerator_Expecter) GetRequeueAfter

func (_e *MockGenerator_Expecter) GetRequeueAfter(appSetGenerator interface{}) *MockGenerator_GetRequeueAfter_Call

GetRequeueAfter is a helper method to define mock.On call

  • appSetGenerator *v1alpha1.ApplicationSetGenerator

func (*MockGenerator_Expecter) GetTemplate

func (_e *MockGenerator_Expecter) GetTemplate(appSetGenerator interface{}) *MockGenerator_GetTemplate_Call

GetTemplate is a helper method to define mock.On call

  • appSetGenerator *v1alpha1.ApplicationSetGenerator

type MockGenerator_GenerateParams_Call

type MockGenerator_GenerateParams_Call struct {
	*mock.Call
}

MockGenerator_GenerateParams_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GenerateParams'

func (*MockGenerator_GenerateParams_Call) Return

func (_c *MockGenerator_GenerateParams_Call) Return(_a0 []map[string]interface{}, _a1 error) *MockGenerator_GenerateParams_Call

func (*MockGenerator_GenerateParams_Call) Run

func (*MockGenerator_GenerateParams_Call) RunAndReturn

type MockGenerator_GetRequeueAfter_Call

type MockGenerator_GetRequeueAfter_Call struct {
	*mock.Call
}

MockGenerator_GetRequeueAfter_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRequeueAfter'

func (*MockGenerator_GetRequeueAfter_Call) Return

func (*MockGenerator_GetRequeueAfter_Call) Run

func (*MockGenerator_GetRequeueAfter_Call) RunAndReturn

type MockGenerator_GetTemplate_Call

type MockGenerator_GetTemplate_Call struct {
	*mock.Call
}

MockGenerator_GetTemplate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetTemplate'

func (*MockGenerator_GetTemplate_Call) Return

func (*MockGenerator_GetTemplate_Call) Run

Jump to